You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@openoffice.apache.org by ms...@apache.org on 2021/03/17 16:58:19 UTC

[openoffice] 03/05: rework of comments in line 413 and 370

This is an automated email from the ASF dual-hosted git repository.

mseidel pushed a commit to branch AOO42X
in repository https://gitbox.apache.org/repos/asf/openoffice.git

commit adbb6a775de2a282d6e19298f40c7a07af9e076a
Author: Peter Kovacs <pe...@apache.org>
AuthorDate: Sun Feb 28 09:04:26 2021 +0100

    rework of comments in line 413 and 370
    
    (cherry picked from commit 1a58a4dd8de890f5ad11c73e8cf7b6c3f003a7d4)
---
 main/sw/inc/shellio.hxx | 6 +++---
 1 file changed, 3 insertions(+), 3 deletions(-)

diff --git a/main/sw/inc/shellio.hxx b/main/sw/inc/shellio.hxx
index b8fbaaa..d7fc99f 100644
--- a/main/sw/inc/shellio.hxx
+++ b/main/sw/inc/shellio.hxx
@@ -366,8 +366,8 @@ public:
 	sal_uLong  ConvertToNew();				// convert AutoText entries (ger: Textbausteine)
 
 	sal_uInt16 GetCount() const;						// return amount of AutoText entries
-	sal_uInt16 GetIndex( const String& ) const;			// return Index of shortnames
-	sal_uInt16 GetLongIndex( const String& ) const;		//Index fuer Langnamen ermitteln
+	sal_uInt16 GetIndex( const String& ) const;			// return Index-Number of shortnames
+	sal_uInt16 GetLongIndex( const String& ) const;		//return Index-Number of langnamen
 	const  String& GetShortName( sal_uInt16 ) const; 	// return a shortname of an index
 	const  String& GetLongName( sal_uInt16 ) const;  	// return longname of an index
 
@@ -410,7 +410,7 @@ SW_DLLPUBLIC SwRead SwGetReaderXML();
 // END source/filter/basflt/fltini.cxx
 
 
-extern sal_Bool SetHTMLTemplate( SwDoc &rDoc ); // HTML templates (pre?)load shellio.cxx
+extern sal_Bool SetHTMLTemplate( SwDoc &rDoc ); // load templates from HTML.vor (see shellio.cxx)
 
 
 /* */